@@ -11,23 +11,25 @@ use nix::{
     unistd,
 };
 
+use async_std;
+use interprocess;
+use libc;
+use nix;
+use signal_hook;
 use signal_hook::consts::*;
 use sysinfo::{ProcessExt, ProcessRefreshKind, System, SystemExt};
+use tempfile::tempfile;
 use zellij_utils::{
-    async_std, channels,
+    channels,
     channels::TrySendError,
     data::Palette,
     errors::prelude::*,
     input::command::{RunCommand, TerminalAction},
-    interprocess,
     ipc::{
         ClientToServerMsg, ExitReason, IpcReceiverWithContext, IpcSenderWithContext,
         ServerToClientMsg,
     },
-    libc, nix,
     shared::default_palette,
-    signal_hook,
-    tempfile::tempfile,
 };
 
 use std::{
@@ -506,11 +508,11 @@ pub trait ServerOsApi: Send + Sync {
     /// Returns the current working directory for a given pid
     fn get_cwd(&self, pid: Pid) -> Option<PathBuf>;
     /// Returns the current working directory for multiple pids
-    fn get_cwds(&self, _pids: Vec<Pid>) -> HashMap<Pid, PathBuf> {
-        HashMap::new()
+    fn get_cwds(&self, _pids: Vec<Pid>) -> (HashMap<Pid, PathBuf>, HashMap<Pid, Vec<String>>) {
+        (HashMap::new(), HashMap::new())
     }
     /// Get a list of all running commands by their parent process id
-    fn get_all_cmds_by_ppid(&self) -> HashMap<String, Vec<String>> {
+    fn get_all_cmds_by_ppid(&self, _post_hook: &Option<String>) -> HashMap<String, Vec<String>> {
         HashMap::new()
     }
     /// Writes the given buffer to a string
@@ -753,9 +755,10 @@ impl ServerOsApi for ServerOsInputOutput {
         None
     }
 
-    fn get_cwds(&self, pids: Vec<Pid>) -> HashMap<Pid, PathBuf> {
+    fn get_cwds(&self, pids: Vec<Pid>) -> (HashMap<Pid, PathBuf>, HashMap<Pid, Vec<String>>) {
         let mut system_info = System::new();
         let mut cwds = HashMap::new();
+        let mut cmds = HashMap::new();
 
         for pid in pids {
             // Update by minimizing information.
@@ -765,17 +768,22 @@ impl ServerOsApi for ServerOsInputOutput {
             if is_found {
                 if let Some(process) = system_info.process(pid.into()) {
                     let cwd = process.cwd();
+                    let cmd = process.cmd();
                     let cwd_is_empty = cwd.iter().next().is_none();
                     if !cwd_is_empty {
                         cwds.insert(pid, process.cwd().to_path_buf());
                     }
+                    let cmd_is_empty = cmd.iter().next().is_none();
+                    if !cmd_is_empty {
+                        cmds.insert(pid, process.cmd().to_vec());
+                    }
                 }
             }
         }
 
-        cwds
+        (cwds, cmds)
     }
-    fn get_all_cmds_by_ppid(&self) -> HashMap<String, Vec<String>> {
+    fn get_all_cmds_by_ppid(&self, post_hook: &Option<String>) -> HashMap<String, Vec<String>> {
         // the key is the stringified ppid
         let mut cmds = HashMap::new();
         if let Some(output) = Command::new("ps")
@@ -794,7 +802,28 @@ impl ServerOsApi for ServerOsInputOutput {
                 let mut line_parts = line_parts.into_iter();
                 let ppid = line_parts.next();
                 if let Some(ppid) = ppid {
-                    cmds.insert(ppid.into(), line_parts.collect());
+                    match &post_hook {
+                        Some(post_hook) => {
+                            let command: Vec<String> = line_parts.clone().collect();
+                            let stringified = command.join(" ");
+                            let cmd = match run_command_hook(&stringified, post_hook) {
+                                Ok(command) => command,
+                                Err(e) => {
+                                    log::error!("Post command hook failed to run: {}", e);
+                                    stringified.to_owned()
+                                },
+                            };
+                            let line_parts: Vec<String> = cmd
+                                .trim()
+                                .split_ascii_whitespace()
+                                .map(|p| p.to_owned())
+                                .collect();
+                            cmds.insert(ppid.into(), line_parts);
+                        },
+                        None => {
+                            cmds.insert(ppid.into(), line_parts.collect());
+                        },
+                    }
                 }
             }
         }
@@ -928,6 +957,22 @@ pub struct ChildId {
     pub shell: Option<Pid>,
 }
 
+fn run_command_hook(
+    original_command: &str,
+    hook_script: &str,
+) -> Result<String, Box<dyn std::error::Error>> {
+    let output = Command::new("sh")
+        .arg("-c")
+        .arg(hook_script)
+        .env("RESURRECT_COMMAND", original_command)
+        .output()?;
+
+    if !output.status.success() {
+        return Err(format!("Hook failed: {}", String::from_utf8_lossy(&output.stderr)).into());
+    }
+    Ok(String::from_utf8(output.stdout)?.trim().to_string())
+}
+
 #[cfg(test)]
 #[path = "./unit/os_input_output_tests.rs"]
 mod os_input_output_tests;
