@@ -13,6 +13,7 @@ use std::collections::{HashMap, HashSet};
 use std::fmt::Debug;
 use std::rc::Rc;
 use std::time::{self, Instant};
+use vte;
 use zellij_utils::input::command::RunCommand;
 use zellij_utils::input::mouse::{MouseEvent, MouseEventType};
 use zellij_utils::pane_size::Offset;
@@ -27,7 +28,6 @@ use zellij_utils::{
     pane_size::SizeInPixels,
     position::Position,
     shared::make_terminal_title,
-    vte,
 };
 
 use crate::ui::pane_boundaries_frame::{FrameParams, PaneFrame};
@@ -213,14 +213,14 @@ impl Pane for TerminalPane {
         key_with_modifier: &Option<KeyWithModifier>,
         raw_input_bytes: Vec<u8>,
         raw_input_bytes_are_kitty: bool,
-        _client_id: Option<ClientId>,
+        client_id: Option<ClientId>,
     ) -> Option<AdjustedInput> {
         // there are some cases in which the terminal state means that input sent to it
         // needs to be adjusted.
         // here we match against those cases - if need be, we adjust the input and if not
         // we send back the original input
 
-        self.reset_selection();
+        self.reset_selection(client_id);
         if !self.grid.bracketed_paste_mode {
             // Zellij itself operates in bracketed paste mode, so the terminal sends these
             // instructions (bracketed paste start and bracketed paste end respectively)
@@ -459,7 +459,7 @@ impl Pane for TerminalPane {
         let pane_title = if self.pane_name.is_empty() && input_mode == InputMode::RenamePane {
             "Enter name..."
         } else if self.pane_name.is_empty() {
-            self.grid.title.as_deref().unwrap_or(&self.pane_title)
+            self.grid.title.as_deref().unwrap_or("")
         } else {
             &self.pane_name
         };
@@ -522,7 +522,7 @@ impl Pane for TerminalPane {
         self.geom.y -= count;
         self.reflow_lines();
     }
-    fn dump_screen(&self, full: bool) -> String {
+    fn dump_screen(&self, full: bool, _client_id: Option<ClientId>) -> String {
         self.grid.dump_screen(full)
     }
     fn clear_screen(&mut self) {
@@ -595,11 +595,11 @@ impl Pane for TerminalPane {
         self.set_should_render(true);
     }
 
-    fn reset_selection(&mut self) {
+    fn reset_selection(&mut self, _client_id: Option<ClientId>) {
         self.grid.reset_selection();
     }
 
-    fn get_selected_text(&self) -> Option<String> {
+    fn get_selected_text(&self, _client_id: ClientId) -> Option<String> {
         self.grid.get_selected_text()
     }
 
@@ -742,7 +742,16 @@ impl Pane for TerminalPane {
     fn add_red_pane_frame_color_override(&mut self, error_text: Option<String>) {
         self.pane_frame_color_override = Some((self.style.colors.exit_code_error.base, error_text));
     }
-    fn clear_pane_frame_color_override(&mut self) {
+    fn add_highlight_pane_frame_color_override(
+        &mut self,
+        text: Option<String>,
+        _client_id: Option<ClientId>,
+    ) {
+        // TODO: if we have a client_id, we should only highlight the frame for this client
+        self.pane_frame_color_override = Some((self.style.colors.frame_highlight.base, text));
+    }
+    fn clear_pane_frame_color_override(&mut self, _client_id: Option<ClientId>) {
+        // TODO: if we have a client_id, we should only clear the highlight for this client
         self.pane_frame_color_override = None;
     }
     fn frame_color_override(&self) -> Option<PaletteColor> {
