@@ -4,10 +4,8 @@ use crate::tab::Pane;
 use crate::ui::boundaries::Boundaries;
 use crate::ui::pane_boundaries_frame::FrameParams;
 use crate::ClientId;
-use std::collections::HashMap;
-use zellij_utils::data::{
-    client_id_to_colors, single_client_color, InputMode, PaletteColor, Style,
-};
+use std::collections::{HashMap, HashSet};
+use zellij_utils::data::{client_id_to_colors, InputMode, PaletteColor, Style};
 use zellij_utils::errors::prelude::*;
 pub struct PaneContentsAndUi<'a> {
     pane: &'a mut Box<dyn Pane>,
@@ -19,6 +17,8 @@ pub struct PaneContentsAndUi<'a> {
     pane_is_stacked_under: bool,
     pane_is_stacked_over: bool,
     should_draw_pane_frames: bool,
+    mouse_is_hovering_over_pane_for_clients: HashSet<ClientId>,
+    current_pane_group: HashMap<ClientId, Vec<PaneId>>,
 }
 
 impl<'a> PaneContentsAndUi<'a> {
@@ -32,6 +32,8 @@ impl<'a> PaneContentsAndUi<'a> {
         pane_is_stacked_under: bool,
         pane_is_stacked_over: bool,
         should_draw_pane_frames: bool,
+        mouse_hover_pane_id: &HashMap<ClientId, PaneId>,
+        current_pane_group: HashMap<ClientId, Vec<PaneId>>,
     ) -> Self {
         let mut focused_clients: Vec<ClientId> = active_panes
             .iter()
@@ -39,6 +41,16 @@ impl<'a> PaneContentsAndUi<'a> {
             .map(|(c_id, _p_id)| *c_id)
             .collect();
         focused_clients.sort_unstable();
+        let mouse_is_hovering_over_pane_for_clients = mouse_hover_pane_id
+            .iter()
+            .filter_map(|(client_id, pane_id)| {
+                if pane_id == &pane.pid() {
+                    Some(*client_id)
+                } else {
+                    None
+                }
+            })
+            .collect();
         PaneContentsAndUi {
             pane,
             output,
@@ -49,6 +61,8 @@ impl<'a> PaneContentsAndUi<'a> {
             pane_is_stacked_under,
             pane_is_stacked_over,
             should_draw_pane_frames,
+            mouse_is_hovering_over_pane_for_clients,
+            current_pane_group,
         }
     }
     pub fn render_pane_contents_to_multiple_clients(
@@ -57,6 +71,10 @@ impl<'a> PaneContentsAndUi<'a> {
     ) -> Result<()> {
         let err_context = "failed to render pane contents to multiple clients";
 
+        // here we drop the fake cursors so that their lines will be updated
+        // and we can clear them from the UI below
+        drop(self.pane.drain_fake_cursors());
+
         if let Some((character_chunks, raw_vte_output, sixel_image_chunks)) =
             self.pane.render(None).context(err_context)?
         {
@@ -135,17 +153,30 @@ impl<'a> PaneContentsAndUi<'a> {
                 .with_context(|| {
                     format!("failed to render fake cursor if needed for client {client_id}")
                 })?;
-            if let Some(colors) = client_id_to_colors(*fake_cursor_client_id, self.style.colors) {
-                if let Some(vte_output) = self.pane.render_fake_cursor(colors.0, colors.1) {
-                    self.output.add_post_vte_instruction_to_client(
-                        client_id,
-                        &format!(
-                            "\u{1b}[{};{}H\u{1b}[m{}",
-                            self.pane.y() + 1,
-                            self.pane.x() + 1,
-                            vte_output
-                        ),
-                    );
+            if let Some(colors) = client_id_to_colors(
+                *fake_cursor_client_id,
+                self.style.colors.multiplayer_user_colors,
+            ) {
+                let cursor_is_visible = self
+                    .pane
+                    .cursor_coordinates()
+                    .map(|(x, y)| {
+                        self.output
+                            .cursor_is_visible(self.pane.x() + x, self.pane.y() + y)
+                    })
+                    .unwrap_or(false);
+                if cursor_is_visible {
+                    if let Some(vte_output) = self.pane.render_fake_cursor(colors.0, colors.1) {
+                        self.output.add_post_vte_instruction_to_client(
+                            client_id,
+                            &format!(
+                                "\u{1b}[{};{}H\u{1b}[m{}",
+                                self.pane.y() + 1,
+                                self.pane.x() + 1,
+                                vte_output
+                            ),
+                        );
+                    }
                 }
             }
         }
@@ -175,6 +206,8 @@ impl<'a> PaneContentsAndUi<'a> {
         client_id: ClientId,
         client_mode: InputMode,
         session_is_mirrored: bool,
+        pane_is_floating: bool,
+        pane_is_selectable: bool,
     ) -> Result<()> {
         let err_context = || format!("failed to render pane frame for client {client_id}");
 
@@ -201,11 +234,17 @@ impl<'a> PaneContentsAndUi<'a> {
                 is_main_client: pane_focused_for_client_id,
                 other_focused_clients: vec![],
                 style: self.style,
-                color: frame_color,
+                color: frame_color.map(|c| c.0),
                 other_cursors_exist_in_session: false,
                 pane_is_stacked_over: self.pane_is_stacked_over,
                 pane_is_stacked_under: self.pane_is_stacked_under,
                 should_draw_pane_frames: self.should_draw_pane_frames,
+                pane_is_floating,
+                content_offset: self.pane.get_content_offset(),
+                mouse_is_hovering_over_pane: self
+                    .mouse_is_hovering_over_pane_for_clients
+                    .contains(&client_id),
+                pane_is_selectable,
             }
         } else {
             FrameParams {
@@ -213,11 +252,17 @@ impl<'a> PaneContentsAndUi<'a> {
                 is_main_client: pane_focused_for_client_id,
                 other_focused_clients,
                 style: self.style,
-                color: frame_color,
+                color: frame_color.map(|c| c.0),
                 other_cursors_exist_in_session: self.multiple_users_exist_in_session,
                 pane_is_stacked_over: self.pane_is_stacked_over,
                 pane_is_stacked_under: self.pane_is_stacked_under,
                 should_draw_pane_frames: self.should_draw_pane_frames,
+                pane_is_floating,
+                content_offset: self.pane.get_content_offset(),
+                mouse_is_hovering_over_pane: self
+                    .mouse_is_hovering_over_pane_for_clients
+                    .contains(&client_id),
+                pane_is_selectable,
             }
         };
 
@@ -242,34 +287,65 @@ impl<'a> PaneContentsAndUi<'a> {
         client_mode: InputMode,
         boundaries: &mut Boundaries,
         session_is_mirrored: bool,
+        pane_is_on_top_of_stack: bool,
+        pane_is_on_bottom_of_stack: bool,
     ) {
         let color = self.frame_color(client_id, client_mode, session_is_mirrored);
-        boundaries.add_rect(self.pane.as_ref(), color);
+        boundaries.add_rect(
+            self.pane.as_ref(),
+            color,
+            pane_is_on_top_of_stack,
+            pane_is_on_bottom_of_stack,
+            self.pane_is_stacked_under,
+        );
     }
     fn frame_color(
         &self,
         client_id: ClientId,
         mode: InputMode,
         session_is_mirrored: bool,
-    ) -> Option<PaletteColor> {
+    ) -> Option<(PaletteColor, usize)> {
+        // (color, color_precedence) (the color_precedence is used
+        // for the no-pane-frames mode)
         let pane_focused_for_client_id = self.focused_clients.contains(&client_id);
-        if let Some(override_color) = self.pane.frame_color_override() {
-            Some(override_color)
+        let pane_is_in_group = self
+            .current_pane_group
+            .get(&client_id)
+            .map(|p| p.contains(&self.pane.pid()))
+            .unwrap_or(false);
+        if self.pane.frame_color_override().is_some() && !pane_is_in_group {
+            self.pane
+                .frame_color_override()
+                .map(|override_color| (override_color, 4))
+        } else if pane_is_in_group && !pane_focused_for_client_id {
+            Some((self.style.colors.frame_highlight.emphasis_0, 2))
+        } else if pane_is_in_group && pane_focused_for_client_id {
+            Some((self.style.colors.frame_highlight.emphasis_1, 3))
         } else if pane_focused_for_client_id {
             match mode {
                 InputMode::Normal | InputMode::Locked => {
                     if session_is_mirrored || !self.multiple_users_exist_in_session {
-                        let colors = single_client_color(self.style.colors); // mirrored sessions only have one focused color
-                        Some(colors.0)
+                        Some((self.style.colors.frame_selected.base, 3))
                     } else {
-                        let colors = client_id_to_colors(client_id, self.style.colors);
-                        colors.map(|colors| colors.0)
+                        let colors = client_id_to_colors(
+                            client_id,
+                            self.style.colors.multiplayer_user_colors,
+                        );
+                        colors.map(|colors| (colors.0, 3))
                     }
                 },
-                _ => Some(self.style.colors.orange),
+                _ => Some((self.style.colors.frame_highlight.base, 3)),
             }
+        } else if self
+            .mouse_is_hovering_over_pane_for_clients
+            .contains(&client_id)
+        {
+            Some((self.style.colors.frame_highlight.base, 1))
         } else {
-            None
+            self.style
+                .colors
+                .frame_unselected
+                .map(|frame| (frame.base, 0))
         }
     }
 }
